==> myfaces-tobago-4.6.0-source-release.zip: tobago-4.6.0/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/MetaRenderer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.renderkit.renderer;

import org.apache.myfaces.tobago.internal.component.AbstractUIMeta;
import org.apache.myfaces.tobago.renderkit.RendererBase;
import org.apache.myfaces.tobago.renderkit.html.HtmlAttributes;
import org.apache.myfaces.tobago.renderkit.html.HtmlElements;
import org.apache.myfaces.tobago.webapp.TobagoResponseWriter;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import java.io.IOException;

public class MetaRenderer extends RendererBase {

  @Override
  public void encodeBegin(final FacesContext facesContext, final UIComponent component) throws IOException {

    final AbstractUIMeta meta = (AbstractUIMeta) component;
    final TobagoResponseWriter writer = getResponseWriter(facesContext);

    writer.startElement(HtmlElements.META);
    writer.writeAttribute(HtmlAttributes.NAME, meta.getName(), true);
    writer.writeAttribute(HtmlAttributes.LANG, meta.getLang(), true);
    writer.writeAttribute(HtmlAttributes.CHARSET, meta.getCharset(), true);
    writer.writeAttribute(HtmlAttributes.HTTP_EQUIV, meta.getHttpEquiv(), true);
    writer.writeAttribute(HtmlAttributes.CONTENT, meta.getContent(), true);
    writer.endElement(HtmlElements.META);
  }
}

==> myfaces-tobago-5.12.0-source-release.zip: tobago-5.12.0/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/MetaRenderer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.renderkit.renderer;

import org.apache.myfaces.tobago.internal.component.AbstractUIMeta;
import org.apache.myfaces.tobago.renderkit.RendererBase;
import org.apache.myfaces.tobago.renderkit.html.HtmlAttributes;
import org.apache.myfaces.tobago.renderkit.html.HtmlElements;
import org.apache.myfaces.tobago.webapp.TobagoResponseWriter;

import javax.faces.context.FacesContext;
import java.io.IOException;

public class MetaRenderer<T extends AbstractUIMeta> extends RendererBase<T> {

  @Override
  public void encodeBeginInternal(final FacesContext facesContext, final T component) throws IOException {

    final TobagoResponseWriter writer = getResponseWriter(facesContext);

    writer.startElement(HtmlElements.META);
    writer.writeAttribute(HtmlAttributes.NAME, component.getName(), true);
    writer.writeAttribute(HtmlAttributes.LANG, component.getLang(), true);
    writer.writeAttribute(HtmlAttributes.CHARSET, component.getCharset(), true);
    writer.writeAttribute(HtmlAttributes.HTTP_EQUIV, component.getHttpEquiv(), true);
    writer.writeAttribute(HtmlAttributes.CONTENT, component.getContent(), true);
    writer.endElement(HtmlElements.META);
  }
}
